@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -16,9 +19,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-lambda-layer-curl",
-    "1.0.708",
+    "1.0.733",
     __name__[0:-6],
-    "cdk-lambda-layer-curl@1.0.708.jsii.tgz",
+    "cdk-lambda-layer-curl@1.0.733.jsii.tgz",
 )
 
 __all__ = [
